#!/bin/sh

#
# Install script for Nexus Personal
#

INSTALL_DIR="/usr/local/lib"


if [ ! $(id -u) = "0" ]; then
  echo "Error: Script not executed by root."
  exit 1;
fi

SCRIPT_DIR=$(cd `dirname $0`&& pwd)
cd $SCRIPT_DIR

if [ "$1" = "u" ]
then
  echo "Uninstalling Nexus Personal"
  rm -rf $INSTALL_DIR/install.sh
  rm -rf $INSTALL_DIR/personal
  rm -rf $INSTALL_DIR/persadm
  rm -f $INSTALL_DIR/libai.so
  rm -f $INSTALL_DIR/libP11.so
  rm -f $INSTALL_DIR/libtokenapi.so
  rm -f $INSTALL_DIR/libCardSiemens.so
  rm -f $INSTALL_DIR/libCardSetec.so
  rm -f $INSTALL_DIR/libCardPrisma.so
  rm -f /usr/local/bin/personal
  rm -f /usr/local/bin/persadm
  rm -f /usr/lib/xulrunner-addons/plugins/libplugins.so
  rm -f /usr/lib/firefox/plugins/libplugins.so
  rm -f /usr/share/applications/personal.desktop
  echo "Uninstallation complete."

elif [ "$1" = "i" ]
then
  echo "Installing Nexus Personal"

  for i in personal personal/config personal/icons personal/lang personal/lang/sv_SE; do
    mkdir $INSTALL_DIR/$i
    if [ $? -ne 0 ]; then
      echo "ERROR: Operation failed. Installation incomplete."
	      exit 1
    fi
  done

  for i in libai.so libP11.so libplugins.so libtokenapi.so libCardSiemens.so libCardSetec.so libCardPrisma.so personal.bin  personal.sh persadm persadm.sh install.*.sh Nexus_Personal_Help_EN_US.htm PersonalUbuntu_ReadMe_EN_US.txt Nexus_Personal_Help_SE.htm PersonalUbuntu_ReadMe_SE.txt Release.txt libBranding.so; do
    cp $i $INSTALL_DIR/personal
    if [ $? -ne 0 ]; then
      echo "ERROR: Operation failed. Installation incomplete."
      exit 1
    fi
  done

  cp Personal.cfg $INSTALL_DIR/personal/config
  if [ $? -ne 0 ]; then
    echo "ERROR: Operation failed. Installation incomplete."
    exit 1
  fi

  cp "nexus_logo_32x32.png" $INSTALL_DIR/personal/icons 
  if [ $? -ne 0 ]; then
    echo "ERROR: Operation failed. Installation incomplete."
    exit 1
  fi

  cp personal.mo $INSTALL_DIR/personal/lang/sv_SE
  if [ $? -ne 0 ]; then
    echo "ERROR: Operation failed. Installation incomplete."
    exit 1
  fi

  cp personal.desktop /usr/share/applications
  if [ $? -ne 0 ]; then
    echo "ERROR: Operation failed. Installation incomplete."
    exit 1
  fi

  for i in libai.so libtokenapi.so; do
    ln -s $INSTALL_DIR/personal/$i $INSTALL_DIR/$i
    if [ $? -ne 0 ]; then
      echo "ERROR: Operation failed. Installation incomplete."
      exit 1
    fi
  done

  ln -s $INSTALL_DIR/personal/personal.sh /usr/local/bin/personal
  if [ $? -ne 0 ]; then
    echo "ERROR: Operation failed. Installation incomplete."
    exit 1
  fi

  ln -s $INSTALL_DIR/personal/persadm.sh /usr/local/bin/persadm
  if [ $? -ne 0 ]; then
    echo "ERROR: Operation failed. Installation incomplete."
    exit 1
  fi
#Install plugin for FF3
  ln -s $INSTALL_DIR/personal/libplugins.so /usr/lib/xulrunner-addons/plugins
  if [ $? -ne 0 ]; then
    echo "WARNING: Failed installing plugin for Firefox 3. Manually add symlink to libplugins.so in your Firefox 3 plugin directory if this browser is to be used."
  fi
#Install plugins for FF2
  if(test -d /usr/lib/firefox/plugins); then
    ln -s $INSTALL_DIR/personal/libplugins.so /usr/lib/firefox/plugins
    if [ $? -ne 0 ]; then
      echo "WARNING: Failed installing plugin for Firefox 2. Manually add symlink to libplugins.so in your Firefox 2 plugin directory if this browser is to be used."
    fi
  fi

  grep -q $INSTALL_DIR /etc/ld.so.conf
  if [ $? -ne 0 ]; then
    echo $INSTALL_DIR >> /etc/ld.so.conf
  fi

  ldconfig

  echo "Installation complete."

else

  echo "usage: install.<version>.sh [i|u]"
  echo "i - install"
  echo "u - uninstall"

fi

